==> kmodemlights-0.4.tar.gz: kmodemlights-0.4/kmodemlights/kmodemlightsdlg.cpp <==
/*
 *   kmodemlights - a moon phase indicator
 *   Copyright (C) 1998  Stephan Kulow
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

#include <qspinbox.h>
#include <qlayout.h>
#include <qwhatsthis.h>
#include <qlineedit.h> 
#include <qgroupbox.h>
#include <qvgroupbox.h>
#include <qcheckbox.h>
#include <qhbox.h>
#include <qgrid.h>

#include <klocale.h>
#include <kapplication.h>
#include <ktabwidget.h>
#include <kpushbutton.h>
#include <kcolorbutton.h>

#include "kmodemlights.h"
#include "light.h"
#include "graph.h"
#include "statusbutton.h"

#include "kmodemlightsdlg.moc"

KModemLightsDlg::KModemLightsDlg(KModemLightsApplet *ap, QWidget *parent, 
				 const char *name)
  : KDialogBase(parent, name, true, i18n("Change Settings"),
		Ok|Cancel|Help),
    applet(ap)
{
  KTabWidget *page = new KTabWidget(this);
  page->setMargin(marginHint());
  setMainWidget(page);

  page->addTab(generateGeneral(), i18n("Behaviour"));
  page->addTab(generateDevice(), i18n("Device"));
  page->addTab(generateColor(), i18n("Colors"));

  connect(this, SIGNAL(helpClicked()), SLOT(help()));
}

QWidget *KModemLightsDlg::generateDevice()
{
  QWidget *tab = new QWidget();
  QVBoxLayout *vbox = new QVBoxLayout(tab, 0, spacingHint());

  QGrid *group = new QGrid(2, tab);
  group->setSpacing(spacingHint());
  vbox->addWidget(group);

  // Device Name
  QLabel *label = new QLabel(i18n("Device:"), group);
  QString text = i18n("<b>This is the name of the device.</b>"
	      "<p>P.e. 'ppp0' for (the first) PPP device.</p>");
  QWhatsThis::add(label, text);  
  deviceWidget = new QLineEdit(applet->modem.deviceName(), group);
  QWhatsThis::add(deviceWidget, text);
  
  // Lockfile Name
  label = new QLabel(i18n("Lockfile:"), group);
  text = i18n("<b>This is the path to the file, that is used to lock"
	      "the device.</b>"
	      "<p>On a standard linux-system this is "
	      "<nobr>'/var/lock/LCK..ttyS1'</nobr> for a modem "
	      "on <nobr>'/dev/ttyS1'</nobr>.</p>");
  QWhatsThis::add(label, text);
  lockFileWidget = new QLineEdit(applet->modem.lockFile(), group);
  QWhatsThis::add(lockFileWidget, text);

  // Connect command
  label = new QLabel(i18n("Connect:"), group);
  text = i18n("<b>This is the command that is executed to go online.</b>"
	      "<p>It is different on different distributions and systems.</p>" 
	      "<p>For a connection configured with kppp it is "
	      "<nobr>'kppp -c &lt;provider&gt;'</nobr>.</p>");
  QWhatsThis::add(label, text);
  connectWidget = new QLineEdit(applet->connectCommand, group);
  QWhatsThis::add(connectWidget, text);

  // Disonnect command
  label = new QLabel(i18n("Disconnect:"), group);
  text = i18n("<b>This is the command that is executed to go offline.</b>"
	      "<p>It is different on different distributions and systems.</p>"
	      "<p>For a connection configured with kppp it is "
	      "<nobr>'kppp -k -q'<nobr>.</p>");
  QWhatsThis::add(label, text);
  disconnectWidget = new QLineEdit(applet->disconnectCommand, group);
  QWhatsThis::add(disconnectWidget, text);

  // Hint to use What's this help
  vbox->addStretch();
  label = new QLabel(i18n("<i>There is help available for all fields on this "
			  "tab, that can be shown with Shift-F1.</i>"), tab);
  label->setTextFormat(Qt::RichText); // does not break the text otherwise
  vbox->addWidget(label);

  return tab;
}

QWidget *KModemLightsDlg::generateGeneral()
{
  QWidget *tab = new QWidget();
  QVBoxLayout *vbox = new QVBoxLayout(tab, 0, spacingHint());

  // **** Behaviour
  QVGroupBox *group = new QVGroupBox(i18n("General"), tab);
  vbox->addWidget(group);
 
  // Frequency
  QHBox *hb = new QHBox(group);
  hb->setSpacing(spacingHint());
  QLabel *label = new QLabel(i18n("Update Frequency:"), hb);
  frequencyWidget = new QSpinBox(1, 5, 1, hb);
  frequencyWidget->setValue(applet->updateFrequency);
  frequencyWidget->setSuffix(" Hz");
  QString text = i18n("<b>This is the frequency the applet is updated.</b>"
	      "<p>A value of 3 means it is updated 3 times a second."
	      "The default value is 5. On extremly slow systems "
	      "you might like to reduce the frequency to lower "
	      "the system-load, mostly the default is O.K.</p>");
  QWhatsThis::add(label, text);
  QWhatsThis::add(frequencyWidget, text);

  // Requesters
  showRequestersWidget = new QCheckBox(i18n("checkback on going on-/offline"), group);
  showRequestersWidget->setChecked(applet->showRequesters);
  text = i18n("<b>Checkback-requester</b>"
	      "<p>Check this box if you don't want a checkback-requester shown "
	      "when you request going on- or offline.</p>");
  QWhatsThis::add(showRequestersWidget, text);

  // **** Graph
  group = new QVGroupBox(i18n("Graph"), tab);
  vbox->addWidget(group);
 
  // Auto range
  autoMaxWidget = new QCheckBox(i18n("Automatic range detection"), group);
  autoMaxWidget->setChecked(applet->graph->autoMax());
  text = i18n("<b>self-adjusting y-range on graph</b>"
	      "<p>Check this box if you want the display range to adapt "
	      "dynamically to the currently displayed values. If you don't "
	      "check this, you have to specify the range you want in the "
	      "field below.</p>");
  QWhatsThis::add(autoMaxWidget, text);

  // MaxValue
  hb = new QHBox(group);
  hb->setSpacing(spacingHint());
  label = new QLabel(i18n("Maximum value:"), hb);
  maxValueWidget = new QLineEdit(QString().setNum(applet->graphMaxValue), hb);
  maxValueWidget->setAlignment(Qt::AlignRight);
  text = i18n("<b>This is the maximum Value of the Graph</b>"
	      "<p>if automatic setting is switched off this determines"
	      "the maximum value the graph can display.</p>");
  QWhatsThis::add(label, text);
  QWhatsThis::add(frequencyWidget, text);

  // signals
  maxValueWidget->setDisabled(autoMaxWidget->isChecked());
  connect(autoMaxWidget, SIGNAL(toggled(bool)), 
	  maxValueWidget, SLOT(setDisabled(bool)));

  // Hint to use What's this help
  vbox->addStretch();
  label = new QLabel(i18n("<i>There is help available for all fields on this "
			  "tab, that can be shown with Shift-F1.</i>"), tab);
  label->setTextFormat(Qt::RichText); // does not break the text otherwise
  vbox->addWidget(label);

  return tab;
}

QLabel *KModemLightsDlg::newCaption(const QString &s, QWidget *w)
{
  QLabel *l = new QLabel(s, w);
  l->setAlignment(Qt::AlignHCenter|Qt::AlignVCenter);
#if 0
  QFont f = font();
  if(f.pointSize()) {
    f.setPointSize(f.pointSize()*0.9);
    l->setFont(f);
  }
#endif

  return l;
}

QWidget *KModemLightsDlg::generateColor()
{
  QWidget *tab = new QWidget();
  QVBoxLayout *vbox = new QVBoxLayout(tab, 0, spacingHint());

  QGroupBox *group = new QGroupBox(3, Qt::Vertical, i18n("LEDs"), tab);
  vbox->add(group);
  group->addSpace(0);
  QLabel *label = new QLabel(i18n("Receive Data:"), group);
  label = new QLabel(i18n("Send Data:"), group);
  label = newCaption(i18n("On"), group);
  rxOn = new KColorButton(group);
  txOn = new KColorButton(group);
  label = newCaption(i18n("Off"), group);
  rxOff = new KColorButton(group);
  txOff = new KColorButton(group);

  group = new QGroupBox(2, Qt::Vertical, i18n("Connection Status"), tab);
  vbox->add(group);
  statusAwait = new KColorButton(group);
  label = newCaption(i18n("Await Connection"), group);
  statusOn = new KColorButton(group);
  label = newCaption(i18n("Connected"), group);

  group = new QGroupBox(2, Qt::Vertical, i18n("Graph"), tab);
  vbox->add(group);
  rxGraph = new KColorButton(group);
  label = newCaption(i18n("Receive"), group);
  txGraph = new KColorButton(group);
  label = newCaption(i18n("Send"), group);
  graphBg = new KColorButton(group);
  label = newCaption(i18n("Background"), group);

  vbox->addStretch();  

  // setup colors in widgets
  rxOn->setColor(applet->lightRx->getColorOn());
  rxOff->setColor(applet->lightRx->getColorOff());
  rxGraph->setColor(applet->graph->getColorA());

  txOn->setColor(applet->lightTx->getColorOn());
  txOff->setColor(applet->lightTx->getColorOff());
  txGraph->setColor(applet->graph->getColorB());

  graphBg->setColor(applet->graph->getColorBg());

  statusAwait->setColor(applet->button->getColor(StatusButton::Wait));
  statusOn->setColor(applet->button->getColor(StatusButton::On));

  return tab;
}

void KModemLightsDlg::help() {
  kapp->invokeHelp(QString::fromLatin1("config"));
}

==> kmodemlights-0.5.tar.gz: kmodemlights-0.5/kmodemlights/kmodemlightsdlg.cpp <==
/*
 *   kmodemlights - a moon phase indicator
 *   Copyright (C) 1998  Stephan Kulow
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

#include <qspinbox.h>
#include <qlayout.h>
#include <qwhatsthis.h>
#include <qlineedit.h> 
#include <qgroupbox.h>
#include <qvgroupbox.h>
#include <qcheckbox.h>
#include <qhbox.h>
#include <qgrid.h>

#include <klocale.h>
#include <kapplication.h>
#include <ktabwidget.h>
#include <kpushbutton.h>
#include <kcolorbutton.h>

#include "kmodemlights.h"
#include "light.h"
#include "graph.h"
#include "statusbutton.h"

#include "kmodemlightsdlg.moc"

KModemLightsDlg::KModemLightsDlg(KModemLightsApplet *ap, QWidget *parent, 
				 const char *name)
  : KDialogBase(parent, name, true, i18n("Change Settings"),
		Ok|Cancel|Help),
    applet(ap)
{
  KTabWidget *page = new KTabWidget(this);
  page->setMargin(marginHint());
  setMainWidget(page);

  page->addTab(generateGeneral(), i18n("Behaviour"));
  page->addTab(generateDevice(), i18n("Device"));
  page->addTab(generateColor(), i18n("Colors"));

  connect(this, SIGNAL(helpClicked()), SLOT(help()));
}

QWidget *KModemLightsDlg::generateDevice()
{
  QWidget *tab = new QWidget();
  QVBoxLayout *vbox = new QVBoxLayout(tab, 0, spacingHint());

  QGrid *group = new QGrid(2, tab);
  group->setSpacing(spacingHint());
  vbox->addWidget(group);

  // Device Name
  QLabel *label = new QLabel(i18n("Device:"), group);
  QString text = i18n("<b>This is the name of the device.</b>"
	      "<p>P.e. 'ppp0' for (the first) PPP device.</p>");
  QWhatsThis::add(label, text);  
  deviceWidget = new QLineEdit(applet->modem.deviceName(), group);
  QWhatsThis::add(deviceWidget, text);
  
  // Lockfile Name
  label = new QLabel(i18n("Lockfile:"), group);
  text = i18n("<b>This is the path to the file, that is used to lock"
	      "the device.</b>"
	      "<p>On a standard linux-system this is "
	      "<nobr>'/var/lock/LCK..ttyS1'</nobr> for a modem "
	      "on <nobr>'/dev/ttyS1'</nobr>.</p>");
  QWhatsThis::add(label, text);
  lockFileWidget = new QLineEdit(applet->modem.lockFile(), group);
  QWhatsThis::add(lockFileWidget, text);

  // Connect command
  label = new QLabel(i18n("Connect:"), group);
  text = i18n("<b>This is the command that is executed to go online.</b>"
	      "<p>It is different on different distributions and systems.</p>" 
	      "<p>For a connection configured with kppp it is "
	      "<nobr>'kppp -c &lt;provider&gt;'</nobr>.</p>");
  QWhatsThis::add(label, text);
  connectWidget = new QLineEdit(applet->connectCommand, group);
  QWhatsThis::add(connectWidget, text);

  // Disonnect command
  label = new QLabel(i18n("Disconnect:"), group);
  text = i18n("<b>This is the command that is executed to go offline.</b>"
	      "<p>It is different on different distributions and systems.</p>"
	      "<p>For a connection configured with kppp it is "
	      "<nobr>'kppp -k -q'<nobr>.</p>");
  QWhatsThis::add(label, text);
  disconnectWidget = new QLineEdit(applet->disconnectCommand, group);
  QWhatsThis::add(disconnectWidget, text);

  // Hint to use What's this help
  vbox->addStretch();
  label = new QLabel(i18n("<i>There is help available for all fields on this "
			  "tab, that can be shown with Shift-F1.</i>"), tab);
  label->setTextFormat(Qt::RichText); // does not break the text otherwise
  vbox->addWidget(label);

  return tab;
}

QWidget *KModemLightsDlg::generateGeneral()
{
  QWidget *tab = new QWidget();
  QVBoxLayout *vbox = new QVBoxLayout(tab, 0, spacingHint());

  // **** Behaviour
  QVGroupBox *group = new QVGroupBox(i18n("General"), tab);
  vbox->addWidget(group);
 
  // Frequency
  QHBox *hb = new QHBox(group);
  hb->setSpacing(spacingHint());
  QLabel *label = new QLabel(i18n("Update Frequency:"), hb);
  frequencyWidget = new QSpinBox(1, 5, 1, hb);
  frequencyWidget->setValue(applet->updateFrequency);
  frequencyWidget->setSuffix(" Hz");
  QString text = i18n("<b>This is the frequency the applet is updated.</b>"
	      "<p>A value of 3 means it is updated 3 times a second."
	      "The default value is 5. On extremly slow systems "
	      "you might like to reduce the frequency to lower "
	      "the system-load, mostly the default is O.K.</p>");
  QWhatsThis::add(label, text);
  QWhatsThis::add(frequencyWidget, text);

  // Requesters
  showRequestersWidget = new QCheckBox(i18n("checkback on going on-/offline"), group);
  showRequestersWidget->setChecked(applet->showRequesters);
  text = i18n("<b>Checkback-requester</b>"
	      "<p>Check this box if you want a checkback-requester shown "
	      "when you request going on- or offline.</p>");
  QWhatsThis::add(showRequestersWidget, text);

  // **** Graph
  group = new QVGroupBox(i18n("Graph"), tab);
  vbox->addWidget(group);
 
  // Auto range
  autoMaxWidget = new QCheckBox(i18n("Automatic range detection"), group);
  autoMaxWidget->setChecked(applet->graph->autoMax());
  text = i18n("<b>self-adjusting y-range on graph</b>"
	      "<p>Check this box if you want the display range to adapt "
	      "dynamically to the currently displayed values. If you don't "
	      "check this, you have to specify the range you want in the "
	      "field below.</p>");
  QWhatsThis::add(autoMaxWidget, text);

  // MaxValue
  hb = new QHBox(group);
  hb->setSpacing(spacingHint());
  label = new QLabel(i18n("Maximum value:"), hb);
  maxValueWidget = new QLineEdit(QString().setNum(applet->graphMaxValue), hb);
  maxValueWidget->setAlignment(Qt::AlignRight);
  text = i18n("<b>This is the maximum Value of the Graph</b>"
	      "<p>if automatic setting is switched off this determines"
	      "the maximum value the graph can display.</p>");
  QWhatsThis::add(label, text);
  QWhatsThis::add(frequencyWidget, text);

  // signals
  maxValueWidget->setDisabled(autoMaxWidget->isChecked());
  connect(autoMaxWidget, SIGNAL(toggled(bool)), 
	  maxValueWidget, SLOT(setDisabled(bool)));

  // Hint to use What's this help
  vbox->addStretch();
  label = new QLabel(i18n("<i>There is help available for all fields on this "
			  "tab, that can be shown with Shift-F1.</i>"), tab);
  label->setTextFormat(Qt::RichText); // does not break the text otherwise
  vbox->addWidget(label);

  return tab;
}

QLabel *KModemLightsDlg::newCaption(const QString &s, QWidget *w)
{
  QLabel *l = new QLabel(s, w);
  l->setAlignment(Qt::AlignHCenter|Qt::AlignVCenter);
#if 0
  QFont f = font();
  if(f.pointSize()) {
    f.setPointSize(f.pointSize()*0.9);
    l->setFont(f);
  }
#endif

  return l;
}

QWidget *KModemLightsDlg::generateColor()
{
  QWidget *tab = new QWidget();
  QVBoxLayout *vbox = new QVBoxLayout(tab, 0, spacingHint());

  QGroupBox *group = new QGroupBox(3, Qt::Vertical, i18n("LEDs"), tab);
  vbox->add(group);
  group->addSpace(0);
  QLabel *label = new QLabel(i18n("Receive Data:"), group);
  label = new QLabel(i18n("Send Data:"), group);
  label = newCaption(i18n("On"), group);
  rxOn = new KColorButton(group);
  txOn = new KColorButton(group);
  label = newCaption(i18n("Off"), group);
  rxOff = new KColorButton(group);
  txOff = new KColorButton(group);

  group = new QGroupBox(2, Qt::Vertical, i18n("Connection Status"), tab);
  vbox->add(group);
  statusAwait = new KColorButton(group);
  label = newCaption(i18n("Await Connection"), group);
  statusOn = new KColorButton(group);
  label = newCaption(i18n("Connected"), group);

  group = new QGroupBox(2, Qt::Vertical, i18n("Graph"), tab);
  vbox->add(group);
  rxGraph = new KColorButton(group);
  label = newCaption(i18n("Receive"), group);
  txGraph = new KColorButton(group);
  label = newCaption(i18n("Send"), group);
  graphBg = new KColorButton(group);
  label = newCaption(i18n("Background"), group);

  vbox->addStretch();  

  // setup colors in widgets
  rxOn->setColor(applet->lightRx->getColorOn());
  rxOff->setColor(applet->lightRx->getColorOff());
  rxGraph->setColor(applet->graph->getColorA());

  txOn->setColor(applet->lightTx->getColorOn());
  txOff->setColor(applet->lightTx->getColorOff());
  txGraph->setColor(applet->graph->getColorB());

  graphBg->setColor(applet->graph->getColorBg());

  statusAwait->setColor(applet->button->getColor(StatusButton::Wait));
  statusOn->setColor(applet->button->getColor(StatusButton::On));

  return tab;
}

void KModemLightsDlg::help() {
  kapp->invokeHelp(QString::fromLatin1("config"));
}
